@@ -87,8 +87,9 @@ class display_volume_detail(DetailView):
                 stat_value = client_data[stat_type]
                 #   Probably not the best way to do this...
                 try:
-                    global_stats[stat_type] = (global_stats.get(stat_type, 0.0) +
-                        stat_value)
+                    global_stats[stat_type] = (
+                        global_stats.get(stat_type, 0.0) + stat_value
+                    )
                 except TypeError:
                     #   This isn't a float, so screw it
                     pass
